from setuptools import setup, find_packages

setup(name="ops-shuv",
      version="0.3",
      description="this contains some kind operations in it.",
      author="shuvam mandal",
      author_email="shuvammandal121@gmail.com",
      packages=["ops-shuv"],
      requires=[],
      )


def add(a,b):
    print('this is the addition',a+b)
def sub(a,b):
    print('this is the subtraction',a-b)
def mul(a,b):
    print('this is the multiplication',a*b)
def div(a,b):
    print('this is the division', a//b)



